package com.ruoyi.ss.transactionBill.service.impl;

import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.ss.channel.domain.Channel;
import com.ruoyi.ss.channel.domain.ChannelQuery;
import com.ruoyi.ss.channel.domain.ChannelVO;
import com.ruoyi.ss.channel.service.ChannelService;
import com.ruoyi.ss.channelWithdraw.service.ChannelWithdrawService;
import com.ruoyi.ss.suit.domain.enums.SuitFeeMode;
import com.ruoyi.ss.suit.domain.enums.SuitFeeType;
import com.ruoyi.ss.transactionBill.domain.vo.TransactionBillVO;
import com.ruoyi.ss.transactionBill.service.TransactionAssembler;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.time.Duration;
import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * @author wjh
 * 2024/5/5
 */
@Service
public class TransactionAssemblerImpl implements TransactionAssembler {

    @Autowired
    private ChannelService channelService;

    /**
     * 拼接渠道名称
     *
     * @param list
     */
    @Override
    public void assembleChannelName(List<TransactionBillVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        ChannelQuery query = new ChannelQuery();
        query.setChannelIds(list.stream().map(TransactionBillVO::getChannelId).filter(Objects::nonNull).distinct().collect(Collectors.toList()));
        Map<Long, ChannelVO> map = channelService.selectMap(query, Channel::getChannelId);

        for (TransactionBillVO bill : list) {
            Channel channel = map.get(bill.getChannelId());
            if (channel != null) {
                bill.setChannelName(channel.getName());
            }
        }
    }

    @Override
    public void assembleSuitSurplus(List<TransactionBillVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }

        for (TransactionBillVO bill : list) {
            // 充值时间
            if (SuitFeeType.rechargeTimeList().contains(bill.getSuitFeeType())) {
                LocalDateTime endTime = bill.getSuitEndTime() == null ? bill.getSuitExpireTime() : bill.getSuitEndTime();
                if (endTime == null) {
                    bill.setSuitSurplus(BigDecimal.ZERO);
                } else {
                    LocalDateTime now = LocalDateTime.now();
                    Duration between = Duration.between(now, endTime);
                    bill.setSuitSurplus(BigDecimal.valueOf(between.getSeconds()));
                }
            }
            // 充值时长
            else if (SuitFeeType.rechargeCountList().contains(bill.getSuitFeeType())) {
                BigDecimal endEle = bill.getSuitEndEle() == null ? bill.getDeviceTotalEle() : bill.getSuitEndEle();
                if (endEle == null) {
                    bill.setSuitSurplus(BigDecimal.ZERO);
                } else {
                    bill.setSuitSurplus(endEle.subtract(bill.getDeviceTotalEle()));
                }
            }
        }
    }
}
