package com.ruoyi.web.controller.ss;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.ValidGroup;
import com.ruoyi.ss.meterReadingRecord.domain.SmMeterReadingRecordQuery;
import com.ruoyi.ss.meterReadingRecord.domain.SmMeterReadingRecordVo;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.ss.meterReadingRecord.domain.SmMeterReadingRecord;
import com.ruoyi.ss.meterReadingRecord.service.ISmMeterReadingRecordService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 抄表记录Controller
 *
 * @author ruoyi
 * @date 2024-03-28
 */
@RestController
@RequestMapping("/system/record")
public class SmMeterReadingRecordController extends BaseController
{
    @Autowired
    private ISmMeterReadingRecordService smMeterReadingRecordService;

    /**
     * 查询抄表记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:record:list')")
    @GetMapping("/list")
    public TableDataInfo list(SmMeterReadingRecordQuery smMeterReadingRecord)
    {
        startPage();
        List<SmMeterReadingRecordVo> list = smMeterReadingRecordService.selectSmMeterReadingRecordList(smMeterReadingRecord);
        return getDataTable(list);
    }

    /**
     * 导出抄表记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:record:export')")
    @Log(title = "抄表记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SmMeterReadingRecordQuery smMeterReadingRecord)
    {
        List<SmMeterReadingRecordVo> list = smMeterReadingRecordService.selectSmMeterReadingRecordList(smMeterReadingRecord);
        ExcelUtil<SmMeterReadingRecordVo> util = new ExcelUtil<SmMeterReadingRecordVo>(SmMeterReadingRecordVo.class);
        util.exportExcel(response, list, "抄表记录数据");
    }

    /**
     * 获取抄表记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:record:query')")
    @GetMapping(value = "/{recordId}")
    public AjaxResult getInfo(@PathVariable("recordId") Long recordId)
    {
        return success(smMeterReadingRecordService.selectSmMeterReadingRecordByRecordId(recordId));
    }

    /**
     * 新增抄表记录
     */
    @PreAuthorize("@ss.hasPermi('system:record:add')")
    @Log(title = "抄表记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SmMeterReadingRecord smMeterReadingRecord)
    {
        return toAjax(smMeterReadingRecordService.insertSmMeterReadingRecord(smMeterReadingRecord));
    }

    /**
     * 修改抄表记录
     */
    @PreAuthorize("@ss.hasPermi('system:record:edit')")
    @Log(title = "抄表记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SmMeterReadingRecord smMeterReadingRecord)
    {
        return toAjax(smMeterReadingRecordService.updateSmMeterReadingRecord(smMeterReadingRecord));
    }

    /**
     * 删除抄表记录
     */
    @PreAuthorize("@ss.hasPermi('system:record:remove')")
    @Log(title = "抄表记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{recordIds}")
    public AjaxResult remove(@PathVariable Long[] recordIds)
    {
        return toAjax(smMeterReadingRecordService.deleteSmMeterReadingRecordByRecordIds(recordIds));
    }

    @ApiOperation("查询最后一条数据，可分组")
    @PreAuthorize("@ss.hasPermi('system:record:query')")
    @GetMapping("/latest")
    public AjaxResult latest(@Validated({ValidGroup.Query.class}) SmMeterReadingRecordQuery dto)
    {
        return success(smMeterReadingRecordService.selectLatest(dto));
    }


    @ApiOperation("查询统计，可分组")
    @PreAuthorize("@ss.hasPermi('system:record:query')")
    @GetMapping("/count")
    public AjaxResult count(@Validated({ValidGroup.Query.class}) SmMeterReadingRecordQuery dto)
    {
        return success(smMeterReadingRecordService.selectCount(dto));
    }
}
